@@ -34,7 +34,8 @@ def print_attrs(d, depth=0):
 def print_h5(file_location):
     """Print a summary of a h5 file."""
     import h5py
-    with h5py.File(file_location, 'r', libver='latest') as f:
+
+    with h5py.File(file_location, "r", libver="latest") as f:
         print("--------AVAILABLE METADATA--------")
         for key, val in f.attrs.items():
             print(key, val)
